@@ -1,5 +1,5 @@
-#' @title Bar plot of the relative gene expression (RE) from a one-factor experiment
-#' @description Bar plot of the relative expression of a gene along with the 95\% confidence interval and significance. There is another function, \code{qpcrTTESTplot}, that is used when the factor has two levels and represents Fold Change. \code{oneFACTORplot} is mainly useful for a one-factor experiment with more than two levels.
+#' @title Bar plot of the relative gene expression (RE) from the \code{qpcrANOVA} output of a one-factor experiment data
+#' @description Bar plot of the relative expression of a gene along with the standard error (se), 95\% confidence interval (ci) and significance. \code{oneFACTORplot} is mainly useful for a one-factor experiment with more than two levels.
 #' @details The \code{oneFACTORplot} function generates the bar plot of the average fold change for target genes along with the significance and the 95\% confidence interval as error bars.
 #' @author Ghader Mirzaghaderi
 #' @export oneFACTORplot
@@ -9,12 +9,12 @@
 #' @import ggplot2
 #' @import lme4
 #' @import agricolae
-#' @param x a data frame created by \link{qpcrANOVA} function via running \code{res <- qpcrANOVA(x)$Result}.
+#' @param res an object created by \code{qpcrANOVA(x)} function on a one factor data such as \code{data_1factor}.
 #' @param width a positive number determining bar width.
 #' @param fill  specify a fill color.
 #' @param y.axis.adjust  a negative or positive number for reducing or increasing the length of the y axis.
 #' @param y.axis.by determines y axis step length.
-#' @param errorbar Type of error bar, can be \code{std} or \code{ci}.
+#' @param errorbar Type of error bar, can be \code{se} or \code{ci}.
 #' @param letter.position.adjust adjust the distance between the grouping letters to the error bars.
 #' @param xlab  the title of the x axis.
 #' @param ylab  the title of the y axis.
@@ -27,15 +27,15 @@
 #' @examples
 #'
 #' # Before plotting, the result needs to be extracted as below:
-#' out <- qpcrANOVA(data_1factor, numberOfrefGenes = 1)$Result
+#' res <- qpcrANOVA(data_1factor, numberOfrefGenes = 1)
 #'
 #' # Bar plot
-#' oneFACTORplot(out,
+#' oneFACTORplot(res,
 #'          width = 0.2,
 #'          fill = "skyblue",
 #'          y.axis.adjust = 0,
 #'          y.axis.by = 0.2,
-#'          errorbar = "std",
+#'          errorbar = "se",
 #'          show.letters = TRUE,
 #'          letter.position.adjust = 0.05,
 #'          ylab = "Relative Expression",
@@ -46,12 +46,12 @@
 
 
 
-oneFACTORplot <- function(x,
+oneFACTORplot <- function(res,
                           width = 0.2,
                           fill = "skyblue",
                           y.axis.adjust = 0.5,
                           y.axis.by = 2,
-                          errorbar = "std",
+                          errorbar = "se",
                           show.letters = TRUE,
                           letter.position.adjust = 0.1,
                           ylab = "Relative Expression",
@@ -61,15 +61,16 @@ oneFACTORplot <- function(x,
                           axis.text.x.angle = 0,
                           axis.text.x.hjust = 0.5){
 
+  x <- res$Result
   RE <- x$RE
-  std <- x$std
   LCL <- x$LCL
   UCL <- x$UCL
+  se <- x$se
 
   q1f1 <- ggplot(x, aes(rownames(x), y = RE, group = rownames(x))) +
     geom_col(color = "black", fill = fill, width = width) +
     #geom_hline(aes(yintercept = 1), col = "red", linetype = 2, show.legend = FALSE) +
-    geom_errorbar(aes(ymin = RE, ymax = RE + std), width = 0.1) +
+    geom_errorbar(aes(ymin = RE, ymax = RE + se), width = 0.1) +
     ylab(ylab) +
     xlab(xlab) +
     theme_bw() +
@@ -77,12 +78,12 @@ oneFACTORplot <- function(x,
           axis.text.y = element_text(size = fontsize, color = "black", angle = 0, hjust = 0.5),
           axis.title  = element_text(size = fontsize),
           legend.text = element_text(size = fontsize)) +
-    scale_y_continuous(breaks = seq(0, max(RE) + max(std) + y.axis.adjust, by = y.axis.by),
-                       limits = c(0, max(RE) + max(std) + y.axis.adjust), expand = c(0, 0))
+    scale_y_continuous(breaks = seq(0, max(RE) + max(se) + y.axis.adjust, by = y.axis.by),
+                       limits = c(0, max(RE) + max(se) + y.axis.adjust), expand = c(0, 0))
 
   if (show.letters) {
     q1f1 <-q1f1 +
-      geom_text(data = x, aes(label = letters, x = rownames(x), y = RE + std + letter.position.adjust),
+      geom_text(data = x, aes(label = letters, x = rownames(x), y = RE + se + letter.position.adjust),
                 vjust = -0.5, size = fontsizePvalue)
   }
   
@@ -125,7 +126,7 @@ oneFACTORplot <- function(x,
   
 
   
-  if(errorbar == "std") {
+  if(errorbar == "se") {
     out1 <- list(plot = q1f1)
     
   } else if(errorbar == "ci") {
